## 1. Running benchmark
```sh
$ go test -bench=. -benchmem
goos: linux
goarch: amd64
pkg: mybench
cpu: AMD Ryzen 7 1700 Eight-Core Processor          
BenchmarkGojaNumericalCalculation-16         	   7220	   143895 ns/op	  13577 B/op	    653 allocs/op
BenchmarkGojaStringManipulation-16           	  34958	    31769 ns/op	   7375 B/op	    102 allocs/op
BenchmarkGopherLuaNumericalCalculation-16    	      4	337104687 ns/op	24032464 B/op	  93862 allocs/op
BenchmarkGopherLuaStringManipulation-16      	     39	 31843282 ns/op	53836705 B/op	  30736 allocs/op
PASS
ok  	mybench	29.245s

```

## 2. Interpretation
The results from your benchmark tests give us a clear comparison between Goja and GopherLua in terms of execution speed, memory usage, and allocation counts for the numerical calculation and string manipulation tasks. Here's how to interpret these results:

### Goja Results

- **Numerical Calculation**:
  - **7220** iterations were completed.
  - Each iteration took **143,895 ns/op** (nanoseconds per operation), indicating the time required to perform the numerical calculation.
  - Memory usage was **13,577 B/op** (bytes per operation), and there were **653 allocs/op** (allocations per operation).

- **String Manipulation**:
  - **34,958** iterations were completed.
  - Each iteration took **31,769 ns/op**, indicating the time required for the string manipulation task.
  - Memory usage was **7,375 B/op**, with **102 allocs/op**.

### GopherLua Results

- **Numerical Calculation**:
  - Only **4** iterations were completed, showing a significantly lower performance compared to Goja.
  - Each iteration took **337,104,687 ns/op**, a substantial increase in time required for the numerical calculation.
  - Memory usage was **24,032,464 B/op**, with **93,862 allocs/op**, indicating much higher memory consumption and allocation count.

- **String Manipulation**:
  - **39** iterations were completed.
  - Each iteration took **31,843,282 ns/op**, which is significantly higher than Goja's performance in string manipulation.
  - Memory usage was **53,836,705 B/op**, with **30,736 allocs/op**, indicating extremely high memory consumption and allocation count.

### Summary

- **Performance**: Goja is significantly faster than GopherLua in both numerical calculations and string manipulations. The difference in execution time (ns/op) is particularly notable, with Goja being much more efficient.

- **Memory Efficiency**: Goja also demonstrates better memory efficiency, using fewer bytes per operation and requiring fewer allocations. This is especially apparent in the numerical calculation benchmark, where GopherLua's memory usage and allocations are orders of magnitude higher.

- **Allocation Count**: The number of allocations per operation is another critical factor for performance, especially in garbage-collected languages like Go. Fewer allocations generally lead to better performance and less pressure on the garbage collector. Again, Goja outperforms GopherLua significantly in this metric.

Based on these results, **Goja** appears to be the more performance-efficient choice for embedding a scripting language in Go applications, especially if your priority is execution speed and memory usage. However, it's important to also consider other factors such as ease of integration, language features, and the specific needs of your application when making your final decision.
